config

package
v0.0.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetAccessToken

func GetAccessToken(flagValue string) string

GetAccessToken returns the access token from the config or flags

func GetDefaultGroup

func GetDefaultGroup() string

GetDefaultGroup returns the default group from the config

func GetOutputFormat

func GetOutputFormat(flagValue string) string

GetOutputFormat returns the output format from the config or flags

func GetTeamDomain

func GetTeamDomain(flagValue string) string

GetTeamDomain returns the team domain from the config or flags

func Save

func Save(config *Config) error

Save saves the configuration to the config file

Types

type Config

type Config struct {
	TeamDomain   string `mapstructure:"team_domain"   json:"team_domain"`
	AccessToken  string `mapstructure:"access_token"  json:"access_token"`
	OutputFormat string `mapstructure:"output_format" json:"output_format"`
	DefaultGroup string `mapstructure:"default_group" json:"default_group"`
}

Config represents the configuration

func Load

func Load() (*Config, error)

Load loads the configuration from the config file

Jump to