Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAccessToken ¶
GetAccessToken returns the access token from the config or flags
func GetDefaultGroup ¶
func GetDefaultGroup() string
GetDefaultGroup returns the default group from the config
func GetOutputFormat ¶
GetOutputFormat returns the output format from the config or flags
func GetTeamDomain ¶
GetTeamDomain returns the team domain from the config or flags
Types ¶
type Config ¶
type Config struct {
TeamDomain string `mapstructure:"team_domain" json:"team_domain"`
AccessToken string `mapstructure:"access_token" json:"access_token"`
OutputFormat string `mapstructure:"output_format" json:"output_format"`
DefaultGroup string `mapstructure:"default_group" json:"default_group"`
}
Config represents the configuration
Click to show internal directories.
Click to hide internal directories.