Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAccessToken ¶
GetAccessToken returns the access token from the config or flags
func GetDefaultGroup ¶
func GetDefaultGroup() string
GetDefaultGroup returns the default group from the config
func GetOutputFormat ¶
GetOutputFormat returns the output format from the config or flags
func GetTeamDomain ¶
GetTeamDomain returns the team domain from the config or flags
Types ¶
Click to show internal directories.
Click to hide internal directories.